<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="kk">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>түз бұрын</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 жаңы жазық</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 минутан уақыт бар</translation>
    </message>
</context>
</TS>